# Table of Contents

- [discovering-sap-ai-agents](<./discovering-sap-ai-agents.md>)
- [SAP LeanIX](<./SAP-LeanIX.md>)
- [Discovering SAP AI Agents](<./Discovering-SAP-AI-Agents.md>)
  - [Overview](<./Discovering-SAP-AI-Agents/Overview.md>)
  - [Prerequisites](<./Discovering-SAP-AI-Agents/Prerequisites.md>)
  - [Step 1: Provision Your Cloud ALM Instance](<./Discovering-SAP-AI-Agents/Step-1-Provision-Your-Cloud-ALM-Instance.md>)
  - [Step 2: Generate a Service Key in Your BTP Cockpit](<./Discovering-SAP-AI-Agents/Step-2-Generate-a-Service-Key-in-Your-BTP-Cockpit.md>)
  - [Step 3: Connect SAP LeanIX to the SAP Cloud ALM API](<./Discovering-SAP-AI-Agents/Step-3-Connect-SAP-LeanIX-to-the-SAP-Cloud-ALM-API.md>)
  - [Linking Discovered Items to Fact Sheets](<./Discovering-SAP-AI-Agents/Linking-Discovered-Items-to-Fact-Sheets.md>)
  - [Viewing Synchronization Logs](<./Discovering-SAP-AI-Agents/Viewing-Synchronization-Logs.md>)
